@@ -71,6 +71,13 @@ class TestYoutubeLists(unittest.TestCase):
         ytie_results = [YoutubeIE()._extract_id(url['url']) for url in result['entries']]
         self.assertFalse('pElCt5oNDuI' in ytie_results)
         self.assertFalse('KdPEApIVdWM' in ytie_results)
+        
+    def test_youtube_playlist_empty(self):
+        dl = FakeDownloader()
+        ie = YoutubePlaylistIE(dl)
+        result = ie.extract('https://www.youtube.com/playlist?list=PLtPgu7CB4gbZDA7i_euNxn75ISqxwZPYx')[0]
+        self.assertIsPlaylist(result)
+        self.assertEqual(len(result['entries']), 0)
 
     def test_youtube_course(self):
         dl = FakeDownloader()
@@ -90,7 +97,7 @@ class TestYoutubeLists(unittest.TestCase):
         self.assertTrue(len(result['entries']) > 90)
         #test autogenerated channel
         result = ie.extract('https://www.youtube.com/channel/HCtnHdj3df7iM/videos')[0]
-        self.assertTrue(len(result['entries']) > 20)
+        self.assertTrue(len(result['entries']) >= 18)
 
     def test_youtube_user(self):
         dl = FakeDownloader()
